from flask import Flask, url_for
from sunrise_sunset_api import *
import geolocation

app = Flask(__name__)


@app.route('/')
def hello_world():
    return _handle_errors('No city is specified')


@app.route('/<city_name>')
def get_data(city_name):
    try:
        rise_time, set_time, time_zone = get_times(city_name)
        return '''
                <HTML>
                    <HEAD>
                        <STYLE>
                           tr.border_bottom td {{border-bottom:1pt dashed rgba(238,130,238,.5); padding-bottom:10px}}
                        </STYLE>
                    </HEAD>
                    <BODY>
                    <DIV style="margin:10px; padding:10px; background-color:rgba(0,255,255,.1); border:rgba(238,130,238,.2) 2px solid; border-radius:25px">
                        <TABLE style="border-spacing:10px">
                            <TR>
                                <TH><H1>{city_name}</H1></TH>
                            </TR>
                            <TR>
                                <TD></TD>
                                <TD><H4>(times are based on "{time_zone}" time zone)</H4></TD>
                            </TR>
                            <TR class="border_bottom">
                                <TD><IMG src="{rise_image}"></IMG></TD>
                                <TD><H3>{rise_time}</H3></TD>
                            </TR>
                            <TR>
                                <TD><IMG src="{set_image}"></IMG></TD>
                                <TD><H3>{set_time}</H3></TD>
                            </TR>
                        </TABLE>
                    </DIV>
                    </BODY>
                </HTML>
                '''.format(
                        city_name = city_name,
                        time_zone = time_zone,
                        rise_image = url_for('static', filename='Weather-Sunrise-icon.png'),
                        set_image = url_for('static', filename='Weather-Sunset-icon.png'),
                        rise_time = rise_time,
                        set_time = set_time
                    )
    except Exception as ex:
        return _handle_errors(ex)


@app.route("/cities")
def get_all_cities():
    try:
        cities = ''
        for city_name in geolocation.get_all_cities(): cities += '<LI>{city_name}</LI>'.format(city_name=city_name)

        return '''
                <HTML>
                    <HEAD>
                        <STYLE>
                           tr.border_bottom td {{border-bottom:1pt dashed rgba(238,130,238,.5); padding-bottom:10px}}
                        </STYLE>
                    </HEAD>
                    <BODY>
                    <DIV style="margin:10px; padding:10px; background-color:rgba(0,255,255,.1); border:rgba(238,130,238,.2) 2px solid; border-radius:25px">
                        <UL>
                    {cities}
                        </UL>
                    </DIV>
                    </BODY>
                </HTML>
                '''.format(cities = cities)
    except Exception as ex:
        return _handle_errors(ex)


def _handle_errors(message):
    return '''
        <HTML>
            <BODY>
                <H1>{msg}</H1>
            </BODY>
        </HTML>
        '''.format(msg=message)


if __name__ == '__main__':
    app.debug = True
    app.run()

