import json
import geolocation
from urllib.request import *
import timezonefinder
import pytz
from datetime import timezone, datetime


def get_times(city_name):
    lat, lng = geolocation.get_geolocation_by_city_name(city_name)
    response = urlopen("https://api.sunrise-sunset.org/json?lat={lat}&lng={lng}".format(lat=lat, lng=lng))
    if response.getcode() == 200:
        sun_data = json.loads(response.read().decode('utf-8'))
        tz_name = timezonefinder.TimezoneFinder().timezone_at(lat=lat, lng=lng)
        return (
            _utc_to_local(sun_data['results']['sunrise'], tz_name),     # sun rise time
            _utc_to_local(sun_data['results']['sunset'], tz_name),      # sun set time
            tz_name                                                     # time zone name
        )
    else:
        raise Exception("Cannot get sunrise-sunset data")


def _utc_to_local(str_utc_time, tz_name):
    utc_time = datetime.strptime(str_utc_time, "%I:%M:%S %p")
    utc_now = datetime.utcnow()
    utc_datetime = utc_time.replace(year=utc_now.year, month=utc_now.month, day=utc_now.day, tzinfo=timezone.utc)
    local_datetime = utc_datetime.astimezone(pytz.timezone(tz_name))
    return local_datetime.strftime("%I:%M:%S %p")


# def _utc_to_local(str_utc_time):
#     utc_time = datetime.strptime(str_utc_time, "%I:%M:%S %p")
#     utc_now = datetime.utcnow()
#     utc_datetime = utc_time.replace(year=utc_now.year, month=utc_now.month, day=utc_now.day)
#     local_datetime = utc_datetime.replace(tzinfo=timezone.utc).astimezone(tz=None)
#     return local_datetime.strftime("%I:%M:%S %p")
